@@ -17,20 +17,16 @@ def mac_address(value: str, /):
 
     Examples:
         >>> mac_address('01:23:45:67:ab:CD')
-        # Output: True
+        True
         >>> mac_address('00:00:00:00:00')
-        # Output: ValidationError(func=mac_address, args={'value': '00:00:00:00:00'})
+        ValidationError(func=mac_address, args={'value': '00:00:00:00:00'})
 
     Args:
         value:
             MAC address string to validate.
 
     Returns:
-        (Literal[True]):
-            If `value` is a valid MAC address.
-        (ValidationError):
-            If `value` is an invalid MAC address.
-
-    > *New in version 0.2.0*.
+        (Literal[True]): If `value` is a valid MAC address.
+        (ValidationError): If `value` is an invalid MAC address.
     """
     return re.match(r"^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$", value) if value else False
